function y = calculateIsotopomerProbability(formula, labels)
% Calculates the probabilities of non-carbon part of a given molecule
% having up to a certain number of extra neutrons.
% Parameters:
%  formula = the atomic formula of the molecule
%  labels = maximum number of extra neutrons

% Mika Miettinen

    nonCarbons = struct('name', {}, 'atomCnt', {});
    formula(1).atomCnt = 0; % strip carbons
    index = 1;
    resMatrix = zeros(1, labels+1);
    % remove atoms that do not appear in molecule
    for i = 1 : length(formula)
        if formula(i).atomCnt > 0
            nonCarbons(index).name = formula(i).name;
            nonCarbons(index).atomCnt = formula(i).atomCnt;
            index = index + 1;
        end
    end
    if isempty(nonCarbons)
        % noncarbon part is empty; +0 is certain, others impossible
        resMatrix(1) = 1;
        y = resMatrix;
        return;
    end

    atomTypes = length(nonCarbons);
    for k = 0 : labels
        combMatrix = createAtomCombMatrix(nonCarbons, k);
        multProbs = zeros(1, atomTypes);
        probabilities = zeros(1, size(combMatrix, 1));
        for i = 1 : size(combMatrix, 1)
            temp = 1;
            for j = 1 : atomTypes
                multProbs(j) = calculateMultinomialProbability(...
                                  nonCarbons(j).name, ...
                                  nonCarbons(j).atomCnt, ...
                                  combMatrix(i, j));
            end
            probabilities(i) = prod(multProbs);
        end
        resMatrix(k+1) = sum(probabilities);
    end

    % normalize the result
    resMatrix = resMatrix / sum(resMatrix);
    y = resMatrix;
