function y = calculateMultinomialProbability(atom, atomCnt, labelCnt)
% Calculates the multinomial probability of atom part of a molecule
% having a given number of labels.
% Parameters:
%  atom = an atom
%  atomCnt = number of atoms in a molecule
%  labelCnt = number of labels in these atoms

% Mika Miettinen

    abundances = getIsotopeAbundances(atom); % get natural abundances
    prob = 0;
    if isempty(abundances) | labelCnt > atomCnt*(length(abundances)-1)
        y = -1.0;
        return;
    elseif labelCnt > atomCnt*(length(abundances)-1)
        y = 0;
        return;
    end
    if length(abundances) == 1
        if labelCnt == 0
            y = 1;
            return;
        else
            y = -1.0;
            return;
        end
    end
    if length(abundances) < 3
        % +2 -isotopes are not possible; only one combination is possible
        coef = calculateMultCoef(atomCnt, atomCnt-labelCnt, labelCnt, 0);
        p0 = abundances(1)^(atomCnt - labelCnt);
        p1 = abundances(2)^labelCnt;
        prob = coef * p0 * p1;
    else
        triples = createTripleMatrix(atomCnt, labelCnt);
        probabilities = zeros(1, size(triples, 1));
        % calculate probabilities for all combinations
        for i = 1 : size(triples, 1)
            coef = calculateMultCoef(atomCnt, triples(i, 1), triples(i, 2), triples(i, 3));
            p0 = abundances(1)^triples(i, 1);
            p1 = abundances(2)^triples(i, 2);
            p2 = abundances(3)^triples(i, 3);
            probabilities(i) = coef * p0 * p1 * p2;
        end
        prob = sum(probabilities);
    end
    y = prob;

function y = calculateMultCoef(nj, k0, k1, k2)
% calculates the multinomial coefficient

    y = factorial(nj) / (factorial(k1) * factorial(k2) * factorial(k0));

