function y = createAtomCombMatrix(formula, numOfLabels)
% Creates a matrix that enumerates all possible combinations
% to get a given amount of extra neutrons.
% Parameters:
%  formula = atomic formula of the (non-carbon part of) molecule
%  numOfLabels = desired number of labels

% Mika Miettinen

    comb = zeros(1, length(formula));
    combM = zeros(0, length(formula));
    maxLabels = zeros(1, length(formula));

    % calculate maximum amount of labels in different atoms of the molecule
    for i = 1 : length(formula)
        abundances = getIsotopeAbundances(formula(i).name);
        maxLabels(i) = formula(i).atomCnt * (length(abundances)-1);
    end

    y = atomCombMatrix(maxLabels, numOfLabels, 1, comb, combM);


function y = atomCombMatrix(maxLabels, free, atom, comb, combMatrix)
% Recursive helper function for createAtomCombMatrix;
% creates the combination matrix.
% Parameters:
%  maxLabels = maximum amount of labels in different atoms
%  free = number of free labels
%  atom = number of current atom
%  comb = one possible combination; column vector of combMatrix
%  combMatrix = the combination matrix

    numOfTypes = length(maxLabels);
    if atom == numOfTypes
        if maxLabels(numOfTypes) >= free
            comb(numOfTypes) = free;
            combMatrix = cat(1, combMatrix, comb);
        end
    else
        n = free;
        if free > maxLabels(atom);
            n = maxLabels(atom);
        end
        for i = n : -1 : 0
            comb(atom) = i;
            combMatrix = atomCombMatrix(maxLabels, free-i, atom+1, comb, combMatrix);
        end
    end

    y = combMatrix;

