function y = parseFormula2(formula)
% parseFormula: Parses atomic formula of a molecule represented as a string.
% Returns an internal representation more suitable for further processing.
%
% Parameters
%   formula: the atomic formula of the molecule as a string


global Elements;

formula = upper(formula);

for j = 1 : length(Elements)
     result(j).name = Elements(j).name;
     result(j).atomCnt = 0;
end

%parse
%first check if two letter abbrevation is found. if not check one letter abbrevations
%Example: SI2  mean two units of silicon, not one sulphur and one iodine
i = 1;
while i < length(formula)
    
    if isempty(str2num(formula(i))) % current symbol is char
        
        if isempty(str2num(formula(i+1))) % next symbol is also char
            
            cand = strcat(formula(i),formula(i+1));
            indOfCand = findElement(cand);
            
            if indOfCand > 0 %two letter cand was found. get the number of atoms
                [numOfAtoms,nextInd] = getNumOfAtoms(formula, i+1);
                result(indOfCand).atomCnt = result(indOfCand).atomCnt + numOfAtoms; 
                i = nextInd;
            else % two letter cand was not found. find one letter cands
                indOfCand = findElement(formula(i));
                if indOfCand > 0
                    result(indOfCand).atomCnt = result(indOfCand).atomCnt + 1;
                    i = i + 1;
                else % atom type was not recognized
                    myMessage('',-22);
                end
            end
        else %current symbol is char and next one number
            indOfCand = findElement(formula(i));
            if indOfCand > 0 %two letter cand was found. get the number of atoms
                [numOfAtoms,nextInd] = getNumOfAtoms(formula, i);
                result(indOfCand).atomCnt = result(indOfCand).atomCnt + numOfAtoms; 
                i = nextInd;
            else 
                % atom type was not recognized
                myMessage('',-22);
            end
        end
    else 
        myMessage('',-22);
    end
end
        
%the last symbol might be still unread

if i <= length(formula) % last symbol is unprocessed
    indOfCand = findElement(formula(i));
    if indOfCand > 0
           result(indOfCand).atomCnt = result(indOfCand).atomCnt + 1;
           i = i + 1;
    else % atom type was not recognized
          myMessage('',-22);
          
      end
  end
  y = result;
 return;
 
 
 function [numOfAtoms, nextInd] = getNumOfAtoms(formula, currInd)
 
 if (currInd == length(formula)) %curr atom type was last symbol in formula string
     numOfAtoms = 1;
     nextInd = currInd;
 else
     currInd = currInd + 1;
     numOfAtoms = str2num(formula(currInd));
     if (isempty(numOfAtoms))
         numOfAtoms = 1;
     else
        currInd = currInd + 1;
        while (currInd <= length(formula) & ~isempty(str2num(formula(currInd)))) % more numbers to come
            numOfAtoms = numOfAtoms * 10 + str2num(formula(currInd));
            currInd =  currInd + 1;
        end
    end
 end
 
 nextInd = currInd;
         
     